//! Chain constants that impose limits on various aspects of smart contract
//! execution.

/// Maximum log size.
pub const MAX_LOG_SIZE: usize = 512;

/// Maximum number of log items.
pub const MAX_NUM_LOGS: usize = 64;
